==> clickstack-framework-1.0.9-sources.jar: com/cloudbees/clickstack/domain/metadata/Syslog.java <==
/*
 * Copyright 2010-2013, CloudBees Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.cloudbees.clickstack.domain.metadata;

import java.util.Arrays;
import java.util.List;

/**
 * @author <a href="mailto:cleclerc@cloudbees.com">Cyrille Le Clerc</a>
 */
public class Syslog extends Resource {

    protected String hostname;
    protected int port;
    protected String facility;
    public static final List<String> TYPES = Arrays.asList("syslog");


    public Syslog(Resource resource) {
        super(resource.getProperties(), resource.getDescriptors());
        if (!checkResource(resource))
            throw new IllegalArgumentException("Incorrect syslog resource definition.");
        hostname = getProperty("hostname");
        port = Integer.parseInt(getProperty("port", "514"));
        facility = getProperty("facility");
    }

    private boolean checkResource(Resource resource) {
        return true;
    }

    public String getHostname() {
        return hostname;
    }

    public int getPort() {
        return port;
    }


    public String getFacility() {
        return facility;
    }
}

==> clickstack-framework-1.0.13-sources.jar: com/cloudbees/clickstack/domain/metadata/Syslog.java <==
/*
 * Copyright 2010-2013, CloudBees Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.cloudbees.clickstack.domain.metadata;

import com.cloudbees.clickstack.domain.environment.Environment;
import com.google.common.base.Strings;

import java.util.Arrays;
import java.util.List;

/**
 * @author <a href="mailto:cleclerc@cloudbees.com">Cyrille Le Clerc</a>
 */
public class Syslog extends Resource {

    protected String hostname;
    protected int port;
    protected String facility;
    protected String appName;
    protected String appHostname;
    public static final List<String> TYPES = Arrays.asList("syslog");


    public Syslog(Resource resource) {
        super(resource.getProperties(), resource.getDescriptors());
        if (!checkResource(resource))
            throw new IllegalArgumentException("Incorrect syslog resource definition.");
        hostname = getProperty("hostname");
        port = Integer.parseInt(getProperty("port", "514"));
        facility = getProperty("facility");
        appName = getProperty("appName");
        appHostname = getProperty("appHostname");
    }

    private boolean checkResource(Resource resource) {
        return true;
    }

    /**
     * Hostname of the syslog server
     */
    public String getHostname() {
        return hostname;
    }

    /**
     * Port of the syslog server
     */
    public int getPort() {
        return port;
    }

    /**
     * Syslog facility
     */
    public String getFacility() {
        return facility;
    }

    /**
     * Application name
     */
    public String getAppName(Environment environment) {
        return Strings.isNullOrEmpty(this.appName) ? environment.appName : this.appName;
    }

    /**
     * Application hostname
     */
    public String getAppHostname(Environment environment) {
        return Strings.isNullOrEmpty(this.appHostname) ? environment.serverInstanceId : this.appHostname;
    }
}
